netapp_ontap.models.volume_flash_pool API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_flash_pool`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeFlashPoolSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeFlashPool object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `cache_eligibility: str GET`

    If this parameter is specified, the command displays information only about the volume or volumes with the specified Flash Pool caching attributes.

    Valid choices:

    - read
    - read_write
    - none
  `cache_retention_priority: str GET`

    If this parameter is specified, the command displays the volumes that match the specified cache retention priority policy. A cache retention priority defines how long the blocks of a volume will be cached in the Flash Pool once they become cold.

    Valid choices:

    - normal
    - low
    - high
  `caching_policy: str GET`

    This optionally specifies the caching policy to apply to the volume. A caching policy defines how the system caches a volume's data in Flash Cache modules. If a caching policy is not assigned to a volume, the system uses the caching policy that is assigned to the containing SVM. If a caching policy is not assigned to the containing SVM, the system uses the default cluster-wide policy.

    Valid choices:

    - none
    - auto
    - meta
    - random_read
    - random_read_write
    - all_read
    - all_read_random_write
    - all
    - noread_random_write
    - meta_random_write
    - random_read_write_random_write
    - all_read_random_write_random_write
    - all_random_write